@@ -1,8 +1,8 @@
-from asyncio import get_event_loop, new_event_loop, create_task
+from asyncio import get_event_loop, new_event_loop
 from asyncio.events import AbstractEventLoop
 from base64 import b64encode
 from time import time, timezone
-from typing import BinaryIO, Union
+from typing import BinaryIO, Union, List
 from uuid import uuid4
 from aiohttp import ClientSession, ClientTimeout
 from json_minify import json_minify
@@ -16,14 +16,23 @@ from .http_client import AminoHttpClient
 
 
 class CommunityClient(AminoHttpClient):
-    def __init__(self, comId: int, loop: AbstractEventLoop = None, session: ClientSession = None, 
-            info: Community = None, settings: dict = None) -> None:
-        self._session: ClientSession = ClientSession(
+    def __init__(self, comId: int,
+        loop: Optional[AbstractEventLoop] = None,
+        session: Optional[ClientSession] = None, 
+        info: Optional[Community] = None,
+        settings: Optional[dict] = None,
+        proxy: Optional[str] = None,
+        proxy_auth: Optional[str] = None
+    ) -> None:
+        self._session: ClientSession = session or ClientSession(
             timeout=ClientTimeout(60), json_serialize=dumps)
         self._loop: AbstractEventLoop = loop or get_event_loop()
         
         self.comId = comId
         self.headers = settings or self.headers
+
+        self.proxy: Optional[str] = proxy
+        self.proxy_auth: Optional[str] = proxy_auth
         
         self.profile: UserProfile = UserProfile(**{})
         self.info: Community = info or Community(**{})
@@ -50,7 +59,7 @@ class CommunityClient(AminoHttpClient):
         if not self.session.closed:
             await self.session.close()
     
-    async def get_invite_codes(self, status: str = "normal", start: int = 0, size: int = 25) -> list[InviteCode]:
+    async def get_invite_codes(self, status: str = "normal", start: int = 0, size: int = 25) -> List[InviteCode]:
         response = await self.get(f"/g/s-x{self.comId}/community/invitation?status={status}&start={start}&size={size}")
         return list(map(lambda o: InviteCode(**o), (await response.json())["communityInvitationList"]))
 
@@ -781,31 +790,31 @@ class CommunityClient(AminoHttpClient):
         response = await self.post(f"/x{self.comId}/s/chat/thread/{chatId}/avchat-reputation")
         return VcReputation(**(await response.json()))
     
-    async def get_all_users(self, type: str = "recent", start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_all_users(self, type: str = "recent", start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/user-profile?type={type}&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
 
-    async def get_online_favorite_users(self, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_online_favorite_users(self, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/user-group/quick-access?type=online&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
 
-    async def get_user_following(self, userId: str, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_user_following(self, userId: str, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/user-profile/{userId}/joined?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
 
-    async def get_user_followers(self, userId: str, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_user_followers(self, userId: str, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/user-profile/{userId}/member?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
 
-    async def get_user_checkins(self, userId: str) -> list[CheckIn]:
+    async def get_user_checkins(self, userId: str) -> List[CheckIn]:
         response = await self.get(f"/x{self.comId}/s/check-in/stats/{userId}?timezone={-timezone // 1000}")
         return list(map(lambda o: CheckIn(**o), (await response.json())))
 
-    async def get_user_blogs(self, userId: str, start: int = 0, size: int = 25) -> list[Blog]:
+    async def get_user_blogs(self, userId: str, start: int = 0, size: int = 25) -> List[Blog]:
         response = await self.get(f"/x{self.comId}/s/blog?type=user&q={userId}&start={start}&size={size}")
         return list(map(lambda o: Blog(**o), (await response.json())["blogList"]))
 
-    async def get_user_wikis(self, userId: str, start: int = 0, size: int = 25) -> list[Wiki]:
+    async def get_user_wikis(self, userId: str, start: int = 0, size: int = 25) -> List[Wiki]:
         response = await self.get(f"/x{self.comId}/s/item?type=user-all&start={start}&size={size}&cv=1.2&uid={userId}")
         return list(map(lambda o: Wiki(**o), (await response.json())["itemList"]))
 
@@ -813,32 +822,32 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/user-profile/{userId}/achievements")
         return Achievement(**(await response.json())["achievements"])
 
-    async def get_influencer_fans(self, userId: str, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_influencer_fans(self, userId: str, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/influencer/{userId}/fans?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())))
 
-    async def get_blocked_users(self, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_blocked_users(self, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/block?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
 
-    async def get_blocker_users(self, start: int = 0, size: int = 25) -> list[str]:
+    async def get_blocker_users(self, start: int = 0, size: int = 25) -> List[str]:
         response = await self.get(f"/x{self.comId}/s/block?start={start}&size={size}")
         return loads(await response.text())["blockerUidList"]
 
-    async def search_users(self, nickname: str, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def search_users(self, nickname: str, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/user-profile?type=name&q={nickname}&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
 
-    async def get_saved_blogs(self, start: int = 0, size: int = 25) -> list[Bookmark]:
+    async def get_saved_blogs(self, start: int = 0, size: int = 25) -> List[Bookmark]:
         response = await self.get(f"/x{self.comId}/s/bookmark?start={start}&size={size}")
         return list(map(lambda o: Bookmark(**o), (await response.json())["bookmarkList"]))
     
-    async def get_leaderboard_info(self, type: int, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_leaderboard_info(self, type: int, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/g/s-x{self.comId}/community/leaderboard?rankingType={type}&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
     
     async def get_tipped_users(self, blogId: str = None, wikiId: str = None, 
-            fileId: str = None, chatId: str = None, start: int = 0, size: int = 25) -> list[TippedUserSummary]:
+            fileId: str = None, chatId: str = None, start: int = 0, size: int = 25) -> List[TippedUserSummary]:
         if blogId:
             url = f"/x{self.comId}/s/blog/{blogId}/tipping/tipped-users-summary?start={start}&size={size}"
 
@@ -856,11 +865,11 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(url)
         return list(map(lambda o: TippedUserSummary(**o), await response.json()))
     
-    async def get_chat_threads(self, start: int = 0, size: int = 25) -> list[Thread]:
+    async def get_chat_threads(self, start: int = 0, size: int = 25) -> List[Thread]:
         response = await self.get(f"/x{self.comId}/s/chat/thread?type=joined-me&start={start}&size={size}")
         return list(map(lambda o: Thread(**o), (await response.json())["threadList"]))
 
-    async def get_public_chat_threads(self, type: str = "recommended", start: int = 0, size: int = 25) -> list[Thread]:
+    async def get_public_chat_threads(self, type: str = "recommended", start: int = 0, size: int = 25) -> List[Thread]:
         response = await self.get(f"/x{self.comId}/s/chat/thread?type=public-all&filterType={type}&start={start}&size={size}")
         return list(map(lambda o: Thread(**o), (await response.json())["threadList"]))
 
@@ -868,12 +877,12 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/chat/thread/{chatId}")
         return Thread(loads(await response.json())["thread"])
 
-    async def get_chat_messages(self, chatId: str, size: int = 25, pageToken: str = None) -> GetMessages:
+    async def get_chat_messages(self, chatId: str, size: int = 25, pageToken: str = None) -> Message:
         if not pageToken: params = f"v=2&pagingType=t&size={size}"
         else: params = f"v=2&pagingType=t&pageToken={pageToken}&size={size}"
 
         response = await self.get(f"/x{self.comId}/s/chat/thread/{chatId}/message?{params}")
-        return GetMessages(**(await response.json()))
+        return list(map(lambda o, p: Message(**o, **p), (data := await response.json())["messageList"], data["paging"]))
 
     async def get_message_info(self, chatId: str, messageId: str) -> Message:
         response = await self.get(f"/x{self.comId}/s/chat/thread/{chatId}/message/{messageId}")
@@ -895,7 +904,7 @@ class CommunityClient(AminoHttpClient):
         else: raise SpecifyType()
     
     async def get_blog_comments(self, blogId: str = None, wikiId: str = None, 
-            fileId: str = None, sorting: str = "newest", start: int = 0, size: int = 25) -> list[Comment]:
+            fileId: str = None, sorting: str = "newest", start: int = 0, size: int = 25) -> List[Comment]:
         if blogId:
             url = f"/x{self.comId}/s/blog/{blogId}/comment?sort={sorting}&start={start}&size={size}"
 
@@ -910,11 +919,11 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(url)
         return list(map(lambda o: Comment(**o), (await response.json())["commentList"]))
     
-    async def get_blog_categories(self, size: int = 25) -> list[BlogCategory]:
+    async def get_blog_categories(self, size: int = 25) -> List[BlogCategory]:
         response = await self.get(f"/x{self.comId}/s/blog-category?size={size}")
         return list(map(lambda o: BlogCategory(**o), (await response.json())["blogCategoryList"]))
 
-    async def get_blogs_by_category(self, categoryId: str, start: int = 0, size: int = 25) -> list[Blog]:
+    async def get_blogs_by_category(self, categoryId: str, start: int = 0, size: int = 25) -> List[Blog]:
         response = await self.get(f"/x{self.comId}/s/blog-category/{categoryId}/blog-list?start={start}&size={size}")
         return list(map(lambda o: Blog(**o), (await response.json())["blogList"]))
 
@@ -922,18 +931,18 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/blog/{quizId}/quiz/result?start={start}&size={size}")
         return QuizRanking(**(await response.json()))
     
-    async def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25) -> list[Comment]:
+    async def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25) -> List[Comment]:
         response = await self.get(f"/x{self.comId}/s/user-profile/{userId}/comment?sort={sorting}&start={start}&size={size}")
         return list(map(lambda o: Comment(**o), (await response.json())["commentList"]))
 
-    async def get_recent_blogs(self, pageToken: str = None, start: int = 0, size: int = 25) -> GetBlogs:
+    async def get_recent_blogs(self, pageToken: str = None, start: int = 0, size: int = 25) -> Blog:
         if not pageToken: params = f"v=2&pagingType=t&start={start}&size={size}"
         else: params = f"v=2&pagingType=t&pageToken={pageToken}&start={start}&size={size}"
         
         response = await self.get(f"/x{self.comId}/s/feed/blog-all?{params}")
-        return GetBlogs(**(await response.json()))
+        return list(map(lambda o, p: Blog(**o, **p), (data := await response.json())["blogList"], data["paging"]))
 
-    async def get_chat_users(self, chatId: str, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_chat_users(self, chatId: str, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/chat/thread/{chatId}/member?start={start}&size={size}&type=default&cv=1.2")
         return list(map(lambda o: UserProfile(**o), (await response.json())["memberList"]))
     
@@ -946,19 +955,19 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/sticker-collection/{sticker_pack_id}?includeStickers=true")
         return StickerCollection(**(await response.json())["stickerCollection"])
 
-    async def get_sticker_packs(self) -> list[StickerCollection]:
+    async def get_sticker_packs(self) -> List[StickerCollection]:
         response = await self.get(f"/x{self.comId}/s/sticker-collection?includeStickers=false&type=my-active-collection")
         return list(map(lambda o: StickerCollection(**o), (await response.json())["stickerCollection"]))
 
-    async def get_store_chat_bubbles(self, start: int = 0, size: int = 25) -> list[StoreItem]:
+    async def get_store_chat_bubbles(self, start: int = 0, size: int = 25) -> List[StoreItem]:
         response = await self.get(f"/x{self.comId}/s/store/items?sectionGroupId=chat-bubble&start={start}&size={size}")
         return list(map(lambda o: StoreItem(**o), (await response.json())["stickerCollection"]))
 
-    async def get_store_stickers(self, start: int = 0, size: int = 25) -> list[StoreItem]:
+    async def get_store_stickers(self, start: int = 0, size: int = 25) -> List[StoreItem]:
         response = await self.get(f"/x{self.comId}/s/store/items?sectionGroupId=sticker&start={start}&size={size}")
         return list(map(lambda o: StoreItem(**o), (await response.json())["stickerCollection"]))
     
-    async def get_community_stickers(self) -> list[StickerCollection]:
+    async def get_community_stickers(self) -> List[StickerCollection]:
         response = await self.get(f"/x{self.comId}/s/sticker-collection?type=community-shared")
         return list(map(lambda o: StickerCollection(**o), (await response.json())))
 
@@ -989,11 +998,11 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/feed/blog-disabled?start={start}&size={size}")
         return list(map(lambda o: Blog(**o), (await response.json())["blogList"]))
 
-    async def get_featured_users(self, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_featured_users(self, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/user-profile?type=featured&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"])) 
 
-    async def review_quiz_questions(self, quizId: str) -> list[Blog.QuizQuestion]:
+    async def review_quiz_questions(self, quizId: str) -> List[Blog.QuizQuestion]:
         response = await self.get(f"/x{self.comId}/s/blog/{quizId}?action=review")
         return list(map(lambda o: Blog.QuizQuestion(**o), (await response.json())["blog"]["quizQuestionList"]))
 
@@ -1010,7 +1019,7 @@ class CommunityClient(AminoHttpClient):
         return list(map(lambda o: Blog(**o), (await response.json())["blogList"]))
     
     async def moderation_history(self, userId: str = None, blogId: str = None, 
-            wikiId: str = None, quizId: str = None, fileId: str = None, size: int = 25) -> list[AdminLog]:
+            wikiId: str = None, quizId: str = None, fileId: str = None, size: int = 25) -> List[AdminLog]:
         if userId:
             objectId = userId
             type = ObjectTypes.USER
@@ -1369,7 +1378,7 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/live-layer/homepage?v=2")
         return (await response.text())["liveLayerList"]
     
-    async def get_online_users(self, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_online_users(self, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:online-members&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
     
@@ -1377,11 +1386,11 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:online-members&start=0&size=1")
         return (await response.json())["userProfileCount"]
     
-    async def get_public_chats(self, start: int = 0, size: int = 25) -> list[Thread]:
+    async def get_public_chats(self, start: int = 0, size: int = 25) -> List[Thread]:
         response = await self.get(f"/x{self.comId}/s/live-layer/public-chats?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["threadList"]))
     
-    async def get_chatting_users(self, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_chatting_users(self, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:users-chatting&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
     
@@ -1389,11 +1398,11 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:users-chatting&start=0&size=1")
         return (await response.json())["userProfileCount"]
 
-    async def get_live_chats(self, start: int = 0, size: int = 25) -> list[Thread]:
+    async def get_live_chats(self, start: int = 0, size: int = 25) -> List[Thread]:
         response = await self.get(f"/x{self.comId}/s/live-layer/public-live-chats?start={start}&size={size}")
         return list(map(lambda o: Thread(**o), (await response.json())["threadList"]))
     
-    async def get_live_chatting_users(self, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_live_chatting_users(self, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:users-live-chatting&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
     
@@ -1401,11 +1410,11 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:users-live-chatting&start=0&size=1")
         return (await response.json())["userProfileCount"]
 
-    async def get_playing_quizzes(self, start: int = 0, size: int = 25) -> list[Blog]:
+    async def get_playing_quizzes(self, start: int = 0, size: int = 25) -> List[Blog]:
         response = await self.get(f"/x{self.comId}/s/live-layer/quizzes?start={start}&size={size}")
         return list(map(lambda o: Blog(**o), (await response.json())["blogList"]))
     
-    async def get_playing_quizzes_users(self, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_playing_quizzes_users(self, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:users-playing-quizzes&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
     
@@ -1413,11 +1422,11 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:users-playing-quizzes&start=0&size=1")
         return (await response.json())["userProfileCount"]
 
-    async def get_browsing_blogs(self, start: int = 0, size: int = 25) -> list[Blog]:
+    async def get_browsing_blogs(self, start: int = 0, size: int = 25) -> List[Blog]:
         response = await self.get(f"/x{self.comId}/s/live-layer/blogs?start={start}&size={size}")
         return list(map(lambda o: Blog(**o), (await response.json())["blogList"]))
     
-    async def get_browsing_blogs_users(self, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_browsing_blogs_users(self, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/x{self.comId}/s/live-layer?topic=ndtopic:x{self.comId}:users-browsing-blogs&start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
     
@@ -1439,7 +1448,7 @@ class CommunityClient(AminoHttpClient):
         response = await self.post(f"/x{self.comId}/s/chat/chat-bubble/{bubbleId}/deactivate")
         return response.status    
     
-    async def get_chat_bubbles(self, chatId: str, start: int = 25, size: int = 25) -> list[ChatBubble]:
+    async def get_chat_bubbles(self, chatId: str, start: int = 25, size: int = 25) -> List[ChatBubble]:
         response = await self.get(f"/x{self.comId}/s/chat/chat-bubble?type=all-my-bubbles?threadId={chatId}?start={start}?size={size}")
         return list(map(lambda o: ChatBubble(**o), (await response.json())["chatBubbleList"]))
     
@@ -1447,7 +1456,7 @@ class CommunityClient(AminoHttpClient):
         response = await self.get(f"/x{self.comId}/s/chat/chat-bubble/{bubbleId}")
         return ChatBubble(**(response.text)["chatBubble"])
 
-    async def get_chat_bubble_templates(self, start: int = 0, size: int = 25) -> list[ChatBubble]:
+    async def get_chat_bubble_templates(self, start: int = 0, size: int = 25) -> List[ChatBubble]:
         response = await self.get(f"/x{self.comId}/s/chat/chat-bubble/templates?start={start}&size={size}")
         return list(map(lambda o: ChatBubble(**o), (await response.json())["templateList"]))
     
@@ -1460,7 +1469,7 @@ class CommunityClient(AminoHttpClient):
         response = await self.post(f"/x{self.comId}/s/chat/chat-bubble/{bubbleId}", bubble)
         return ChatBubble(**(response.text)["chatBubble"])
 
-    async def send_active_object(self, timers: list[dict], timezone: int = 0, flags: int = 0):
+    async def send_active_object(self, timers: List[dict], timezone: int = 0, flags: int = 0):
         data = {
             "userActiveTimeChunkList": timers, 
             "optInAdsFlags": flags, 
@@ -1471,3 +1480,4 @@ class CommunityClient(AminoHttpClient):
         data = json_minify(dumps(data))
         response = await self.post(f"/x{self.comId}/s/community/stats/user-active-time", data=data)
         return response.status
+
