@@ -2,7 +2,7 @@ import base64
 import locale
 import io
 
-from typing import BinaryIO, Union
+from typing import BinaryIO, List, Union
 from uuid import uuid4
 from zipfile import ZIP_DEFLATED, ZipFile
 from aiohttp import ClientSession, ClientTimeout
@@ -21,14 +21,21 @@ from .websocket import WebSocketClient
 
 
 class Client(AminoHttpClient):
-    def __init__(self, loop: AbstractEventLoop = None, deviceId: str = None) -> None:
+    def __init__(self,
+        loop: Optional[AbstractEventLoop] = None,
+        deviceId: Optional[str] = None,
+        proxy: Optional[str] = None,
+        proxy_auth: Optional[str] = None
+    ) -> None:
+            
         self._session: ClientSession = ClientSession(
             timeout=ClientTimeout(60), json_serialize=dumps)
         self._loop: AbstractEventLoop = loop or get_event_loop()
 
+        self.proxy: Optional[str] = proxy
+        self.proxy_auth: Optional[str] = proxy_auth
         self.authenticated: bool = False
-        self.deviceId: str = deviceId or self._loop.run_until_complete(
-                    generate_device(self._session))
+        self.deviceId: str = deviceId or generate_device_sync()
 
         self.auth: Auth = Auth(**{})
         self.account: Account = Account(**{})
@@ -74,7 +81,7 @@ class Client(AminoHttpClient):
             self.websocket.emitter.on(event, callback)
         return callback
     
-    async def get_community_client(self, comId: str = None, aminoId: str = None, 
+    async def initialize_community(self, comId: str = None, aminoId: str = None, 
             get_info: bool = True, community: Community = None) -> CommunityClient:
         if aminoId:
             comId = (await self.search_community(aminoId))[0].comId
@@ -84,9 +91,10 @@ class Client(AminoHttpClient):
         
         if not aminoId and not comId: raise NoCommunity()
 
-        return CommunityClient(comId, self._loop, self._session, community, self.headers)
+        return CommunityClient(comId, self._loop, self._session,
+                community, self.headers, self.proxy, self.proxy_auth)
     
-    def run(self, email: str, password: str, sid: str = None) -> Auth:
+    def run(self, email: str = None, password: str = None, sid: str = None) -> Auth:
 
         if not sid:
             self._loop.run_until_complete(self.login(email, password))
@@ -160,6 +168,8 @@ class Client(AminoHttpClient):
 
         self.auth: Auth = Auth(account=self.account, auid=self.userId,
                 profile=self.profile, sid=self.sid, deviceId=self.deviceId)
+        self.websocket.auth = self.auth
+        
         return self.auth
     
     async def register(self, nickname: str, email: str, password: str, code: str) -> Auth:
@@ -238,6 +248,7 @@ class Client(AminoHttpClient):
             data["purpose"] = "reset-password"
 
         response = await self.post(f"/g/s/auth/request-security-validation", data)
+        print(response.status)
         return response.status
     
     async def activate_account(self, email: str, code: str) -> int:
@@ -309,7 +320,7 @@ class Client(AminoHttpClient):
         response = await self.get(f"/g/s-x{comId}/community/info")
         return Community(**(await response.json())["community"])
     
-    async def get_account_communities(self, start: int = 0, size: int = 25) -> list[Community]:
+    async def get_account_communities(self, start: int = 0, size: int = 25) -> List[Community]:
         response = await self.get(f"/g/s/community/joined?v=1&start={start}&size={size}")
         return list(map(lambda o: Community(**o), (await response.json())["communityList"])) 
     
@@ -324,11 +335,11 @@ class Client(AminoHttpClient):
         response = await self.get(f"/g/s/chat/thread/{chatId}")
         return Thread(**(await response.json())["thread"])
     
-    async def get_chat_threads(self, start: int = 0, size: int = 25) -> list[Thread]:
+    async def get_chat_threads(self, start: int = 0, size: int = 25) -> List[Thread]:
         response = await self.get(f"/g/s/chat/thread?type=joined-me&start={start}&size={size}")
         return list(map(lambda o: Thread(**o), (await response.json())["threadList"]))
     
-    async def get_chat_users(self, chatId: str, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_chat_users(self, chatId: str, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/g/s/chat/thread/{chatId}/member?start={start}&size={size}&type=default&cv=1.2")
         return list(map(lambda o: UserProfile(**o), (await response.json())["memberList"]))
     
@@ -379,26 +390,26 @@ class Client(AminoHttpClient):
         response = await self.get(f"/g/s/chat/thread/{chatId}/message/{messageId}")
         return Message(**(await response.json())["message"])
     
-    async def get_chat_messages(self, chatId: str, size: int = 25, pageToken: str = None):
+    async def get_chat_messages(self, chatId: str, size: int = 25, pageToken: str = None) -> Message:
         if not pageToken: params = f"v=2&pagingType=t&size={size}"
         else: params = f"v=2&pagingType=t&pageToken={pageToken}&size={size}"
 
         response = await self.get(f"/g/s/chat/thread/{chatId}/message?{params}")
-        return GetMessages(**(await response.json()))
+        return list(map(lambda o, p: Message(**o, **p), (js := await response.json())["messageList"], js["paging"]))
     
-    async def get_user_following(self, userId: str, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_user_following(self, userId: str, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/g/s/user-profile/{userId}/joined?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
 
-    async def get_user_followers(self, userId: str, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_user_followers(self, userId: str, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/g/s/user-profile/{userId}/member?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
 
-    async def get_blocked_users(self, start: int = 0, size: int = 25) -> list[UserProfile]:
+    async def get_blocked_users(self, start: int = 0, size: int = 25) -> List[UserProfile]:
         response = await self.get(f"/g/s/block?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["userProfileList"]))
     
-    async def get_blocker_users(self, start: int = 0, size: int = 25) -> list[str]:
+    async def get_blocker_users(self, start: int = 0, size: int = 25) -> List[str]:
         response = await self.get(f"/g/s/block/full-list?start={start}&size={size}")
         return (await response.json())["blockerUidList"]
 
@@ -414,19 +425,19 @@ class Client(AminoHttpClient):
         response = await self.get(f"/g/s/blog/{quizId}")
         return Blog(**(await response.json())["blog"])
     
-    async def get_blog_comments(self, blogId: str, sorting: str = "newest", start: int = 0, size: int = 25) -> list[Comment]:
+    async def get_blog_comments(self, blogId: str, sorting: str = "newest", start: int = 0, size: int = 25) -> List[Comment]:
         response = await self.get(f"/g/s/blog/{blogId}/comment?sort={sorting}&start={start}&size={size}")
         return list(map(lambda o: Comment(**o), (await response.json())["commentList"]))
     
-    async def get_quiz_comments(self, quizId: str, sorting: str = "newest", start: int = 0, size: int = 25) -> list[Comment]:
+    async def get_quiz_comments(self, quizId: str, sorting: str = "newest", start: int = 0, size: int = 25) -> List[Comment]:
         response = await self.get(f"/g/s/blog/{quizId}/comment?sort={sorting}&start={start}&size={size}")
         return list(map(lambda o: Comment(**o), (await response.json())["commentList"]))
 
-    async def get_wiki_comments(self, wikiId: str, sorting: str = "newest", start: int = 0, size: int = 25) -> list[Comment]:
+    async def get_wiki_comments(self, wikiId: str, sorting: str = "newest", start: int = 0, size: int = 25) -> List[Comment]:
         response = await self.get(f"/g/s/item/{wikiId}/comment?sort={sorting}&start={start}&size={size}")
         return list(map(lambda o: Comment(**o), (await response.json())["commentList"]))
     
-    async def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25) -> list[Comment]:
+    async def get_wall_comments(self, userId: str, sorting: str, start: int = 0, size: int = 25) -> List[Comment]:
         response = await self.get(f"/g/s/user-profile/{userId}/g-comment?sort={sorting}&start={start}&size={size}")
         return list(map(lambda o: Comment(**o), (await response.json())["commentList"]))
     
@@ -754,11 +765,11 @@ class Client(AminoHttpClient):
         response = await self.post(f"/g/s/account/change-amino-id", data)
         return response.status
     
-    async def get_linked_communities(self, userId: str) -> list[Community]:
+    async def get_linked_communities(self, userId: str) -> List[Community]:
         response = await self.get(f"/g/s/user-profile/{userId}/linked-community")
         return list(map(lambda o: Community(**o), (await response.json())["linkedCommunityList"]))
 
-    async def get_unlinked_communities(self, userId: str) -> list[Community]:
+    async def get_unlinked_communities(self, userId: str) -> List[Community]:
         response = await self.get(f"/g/s/user-profile/{userId}/linked-community")
         return list(map(lambda o: Community(**o), (await response.json())["unlinkedCommunityList"]))
 
@@ -899,7 +910,7 @@ class Client(AminoHttpClient):
         response = await self.get(f"/g/s/membership?force=true")
         return Membership(**(await response.json()))
 
-    async def get_ta_announcements(self, lang: str = "en", start: int = 0, size: int = 25) -> list[Blog]:
+    async def get_ta_announcements(self, lang: str = "en", start: int = 0, size: int = 25) -> List[Blog]:
         response = await self.get(f"/g/s/announcement?language={lang}&start={start}&size={size}")
         return list(map(lambda o: Blog(**o), (await response.json())["blogList"]))
 
@@ -907,7 +918,7 @@ class Client(AminoHttpClient):
         response = await self.get(f"/g/s/wallet")
         return Wallet(**(await response.json())["wallet"])
 
-    async def get_wallet_history(self, start: int = 0, size: int = 25) -> list[Transaction]:
+    async def get_wallet_history(self, start: int = 0, size: int = 25) -> List[Transaction]:
         response = await self.get(f"/g/s/wallet/coin/history?start={start}&size={size}")
         return list(map(lambda o: Transaction(**o), (await response.json())["coinHistoryList"]))
 
@@ -917,7 +928,7 @@ class Client(AminoHttpClient):
 
     async def get_link_info(self, code: str) -> Link:
         response = await self.get(f"/g/s/link-resolution?q={code}")
-        return Link(**(await response.json())["linkInfoV2"]["extensions"])
+        return Link(**(ext := (await response.json())["linkInfoV2"]["extensions"]), **ext["linkInfo"])
     
     async def get_from_id(self, objectId: str, objectType: int, comId: str = None) -> Link:
         data = {
@@ -1051,7 +1062,7 @@ class Client(AminoHttpClient):
         response = await self.post(f"{self.api}/g/s/chat/thread/apply-bubble", data)
         return response.status
     
-    async def get_chat_bubbles(self, chatId: str, start: int = 25, size: int = 25) -> list[ChatBubble]:
+    async def get_chat_bubbles(self, chatId: str, start: int = 25, size: int = 25) -> List[ChatBubble]:
         response = await self.get(f"{self.api}/g/s/chat/chat-bubble?type=all-my-bubbles?threadId={chatId}?start={start}?size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["chatBubbleList"]))
     
@@ -1059,7 +1070,7 @@ class Client(AminoHttpClient):
         response = await self.get(f"{self.api}/g/s/chat/chat-bubble/{bubbleId}")
         return ChatBubble(**(response.text)["chatBubble"])
 
-    async def get_chat_bubble_templates(self, start: int = 0, size: int = 25) -> list[ChatBubble]:
+    async def get_chat_bubble_templates(self, start: int = 0, size: int = 25) -> List[ChatBubble]:
         response = await self.get(f"{self.api}/g/s/chat/chat-bubble/templates?start={start}&size={size}")
         return list(map(lambda o: UserProfile(**o), (await response.json())["templateList"]))
     
