@@ -1,21 +1,26 @@
+import aiohttp
+import requests
+
 from time import time
+from typing import Any
 from ujson import loads
 from base64 import b64decode
 from functools import reduce
-from aiohttp import ClientSession
-from requests import Session
 
-ED_API = "http://aminoed.uk.to/api"
+sync_session = requests.Session()
+session = aiohttp.ClientSession()
 
 
-async def generate_device(session: ClientSession, data: str = time()) -> str:
-    response = await session.get(f"{ED_API}/generator/ndcdeviceid?data={str(data)}")
-    return (await response.json(content_type=None))["message"]
+def generate_device_sync() -> str:
+    return sync_session.get("https://ed-generators.herokuapp.com/device").text
     
 
-async def _generate_signature(session: ClientSession, data: str) -> str:
-    response = await session.get(f"{ED_API}/generator/ndc-msg-sig?data={str(data)}")
-    return (await response.json(content_type=None))["message"]
+async def generate_device(data: str = None) -> str:
+    return await (await session.get("https://ed-generators.herokuapp.com/device" + f"?data={data}" if data else "")).text()
+    
+
+async def generate_signature(data: Any) -> str:
+    return await (await session.post("https://ed-generators.herokuapp.com/signature", data=data)).text()
 
 
 def get_timers(size: int) -> list[dict[str, int]]:
