@@ -1,5 +1,6 @@
-from pydantic import BaseModel, Field, validator
-from typing import Optional, Any, Union
+import sys
+from pydantic import BaseModel, Field
+from typing import List, Optional, Any, Union, Dict
 from datetime import datetime
 
 
@@ -33,7 +34,7 @@ class AvatarFrame(BaseModel):
     icon:                Optional[str]
     frameId:             Optional[str]
     ownershipStatus:     Optional[int]
-    extensions:          Optional[dict]
+    extensions:          Optional[Dict]
     uid:                 Optional[str]
     version:             Optional[int]
     isGloballyAvailable: Optional[bool]
@@ -43,7 +44,7 @@ class AvatarFrame(BaseModel):
     config:              Optional[Config]
     status:              Optional[int]
     name:                Optional[str]
-    availableNdcIds:     Optional[list[int]]
+    availableNdcIds:     Optional[List[int]]
     modifiedTime:        Optional[datetime]
     createdTime:         Optional[datetime]
     isNew:               Optional[bool]
@@ -56,7 +57,7 @@ class Account(BaseModel):
             lastClientType: Optional[int]
 
         deviceInfo:      Optional[DeviceInfo]
-        popupConfig:     Optional[dict]
+        popupConfig:     Optional[Dict]
         contentLanguage: Optional[str]
         adsFlags:        Optional[str]
         adsLevel:        Optional[int]
@@ -97,7 +98,7 @@ class UserProfile(BaseModel):
 
     class Extensions(BaseModel):
         class Style(BaseModel):
-            backgroundMediaList: Optional[list[list]]
+            backgroundMediaList: Optional[List[List]]
 
         style: Optional[Style]
 
@@ -165,13 +166,13 @@ class Community(BaseModel):
             status: Optional[int]
             type:   Optional[int]
 
-        rankingTable:                    Optional[list[RankingTableItem]]
+        rankingTable:                    Optional[List[RankingTableItem]]
         frontPageLayout:                 Optional[int]
-        leaderboardStyle:                Optional[dict]
-        newsfeedPages:                   Optional[list[NewsFeedPage]]
+        leaderboardStyle:                Optional[Dict]
+        newsfeedPages:                   Optional[List[NewsFeedPage]]
         facebookAppIdList:               Optional[Any]
         hasPendingReviewRequest:         Optional[bool]
-        joinedBaselineCollectionIdList:  Optional[list]
+        joinedBaselineCollectionIdList:  Optional[List]
         defaultRankingTypeInLeaderboard: Optional[int]
         welcomeMessageText:              Optional[Any]
         pollMinFullBarVoteCount:         Optional[int]
@@ -207,9 +208,9 @@ class Community(BaseModel):
                     reputation: Optional[int]
 
                 enabled:                Optional[bool]
-                leaderboardList:        Optional[list[Leaderboard]]
+                leaderboardList:        Optional[List[Leaderboard]]
                 leaderboardEnabled:     Optional[bool]
-                rankingTable:           Optional[list[Table]]
+                rankingTable:           Optional[List[Table]]
                 defaultLeaderboardType: Optional[int]
 
             class Chat(BaseModel):
@@ -312,13 +313,13 @@ class Community(BaseModel):
 
             welcomeMessage:                 Optional[WelcomeMessage]
             disableLiveLayerVisible:        Optional[bool]
-            joinedTopicIdList:              Optional[list[int]]
+            joinedTopicIdList:              Optional[List[int]]
             disableLocation:                Optional[bool]
             premiumFeatureEnabled:          Optional[bool]
             onlyAllowOfficialTag:           Optional[bool]
             videoUploadPolicy:              Optional[int]
             accountMembershipEnabled:       Optional[bool]
-            joinedBaselineCollectionIdList: Optional[list]
+            joinedBaselineCollectionIdList: Optional[List]
             invitePermission:               Optional[int]
             hasPendingReviewRequest:        Optional[bool]
             disableLiveLayerActive:         Optional[bool]
@@ -329,15 +330,15 @@ class Community(BaseModel):
                 class IdObj(BaseModel):
                     id: Optional[str]
 
-                navigation: Optional[list[IdObj]]
+                navigation: Optional[List[IdObj]]
 
             class LeftSidePanel(BaseModel):
                 class Navigation(BaseModel):
                     class IdObj(BaseModel):
                         id: Optional[str]
 
-                    level2: Optional[list[IdObj]]
-                    level1: Optional[list[IdObj]]
+                    level2: Optional[List[IdObj]]
+                    level1: Optional[List[IdObj]]
 
                 class Style(BaseModel):
                     iconColor: Optional[str]
@@ -354,8 +355,8 @@ class Community(BaseModel):
                 alias: Optional[Any]
                 id:    Optional[str]
 
-            defaultList: Optional[list[DefaultObject]]
-            customList:  Optional[list]
+            defaultList: Optional[List[DefaultObject]]
+            customList:  Optional[List]
 
         module:     Optional[Module]
         appearance: Optional[Appearance]
@@ -364,18 +365,18 @@ class Community(BaseModel):
 
     icon:                               Optional[str]
     configuration:                      Optional[Configuration]
-    communityHeadList:                  Optional[list[UserProfile]]
+    communityHeadList:                  Optional[List[UserProfile]]
     status:                             Optional[int]
     probationStatus:                    Optional[int]
-    influencerList:                     Optional[list[UserProfile]]
-    listedStatus:                       Optional[int]
+    influencerList:                     Optional[List[UserProfile]]
+    ListedStatus:                       Optional[int]
     advancedSettings:                   Optional[AdvancedSettings]
     searchable:                         Optional[bool]
     communityHeat:                      Optional[int]
     endpoint:                           Optional[str]
     joinType:                           Optional[int]
     modifiedTime:                       Optional[datetime]
-    userAddedTopicList:                 Optional[list[UserAddedTopic]]
+    userAddedTopicList:                 Optional[List[UserAddedTopic]]
     content:                            Optional[Any]
     comId:                              Optional[int] = Field(alias="ndcId")
     mediaList:                          Optional[Any]
@@ -388,24 +389,24 @@ class Community(BaseModel):
     link:                               Optional[str]
     agent:                              Optional[UserProfile]
     themePack:                          Optional[ThemePack]
-    activeInfo:                         Optional[dict]
+    activeInfo:                         Optional[Dict]
     templateId:                         Optional[int]
     tagline:                            Optional[str]
     createdTime:                        Optional[datetime]
     extensions:                         Optional[Any]
-    promotionalMediaList:               Optional[list[list]]
+    promotionalMediaList:               Optional[List[List]]
 
 
 class ChatBubble(BaseModel):
     class Config(BaseModel):
         status:               Optional[int]
-        allowedSlots:         Optional[list[dict]]
+        allowedSlots:         Optional[List[Dict]]
         name:                 Optional[str]
-        contentInsets:        Optional[list[int]]
-        zoomPoint:            Optional[list[int]]
+        contentInsets:        Optional[List[int]]
+        zoomPoint:            Optional[List[int]]
         version:              Optional[int]
         linkColor:            Optional[str]
-        slots:                Optional[list[dict]]
+        slots:                Optional[List[Dict]]
         backgroundPath:       Optional[str]
         id:                   Optional[str]
         color:                Optional[str]
@@ -424,7 +425,7 @@ class ChatBubble(BaseModel):
     ownershipStatus: Optional[int]
     version:         Optional[int]
     backgroundImage: Optional[str]
-    extensions:      Optional[dict]
+    extensions:      Optional[Dict]
     deletable:       Optional[bool]
     templateId:      Optional[str]
     createdTime:     Optional[datetime]
@@ -439,7 +440,7 @@ class TipInfo(BaseModel):
         icon:  Optional[str]
 
     tipCustomOption: Optional[TipOption]
-    tipOptionList:   Optional[list[TipOption]]
+    tipOptionList:   Optional[List[TipOption]]
     tipMaxCoin:      Optional[int]
     tippersCount:    Optional[int]
     tippable:        Optional[bool]
@@ -458,9 +459,9 @@ class Thread(BaseModel):
         isAlias:                 Optional[bool]
         name:                    Optional[str]
         contentPoolId:           Optional[str]
-        subTopicList:            Optional[list]
+        subTopicList:            Optional[List]
         coverImage:              Optional[str]
-        aliasTopicList:          Optional[list]
+        aliasTopicList:          Optional[List]
         advancedCommunityStatus: Optional[int]
         increaseId:              Optional[int]
         visibility:              Optional[int]
@@ -471,7 +472,7 @@ class Thread(BaseModel):
         scope:                   Optional[int]
         advancedStatus:          Optional[int]
         isLocked:                Optional[bool]
-        tabList:                 Optional[list]
+        tabList:                 Optional[List]
         objectMappingScore:      Optional[int]
 
     class Member(BaseModel):
@@ -495,17 +496,17 @@ class Thread(BaseModel):
     class Extensions(BaseModel):
         class ScreeningRoomPermission(BaseModel):
             action:  Optional[int]
-            uidList: Optional[list]
+            uidList: Optional[List]
 
         screeningRoomPermission:      Optional[ScreeningRoomPermission]
         viewOnly:                     Optional[bool]
-        coHost:                       Optional[list[str]]
+        coHost:                       Optional[List[str]]
         language:                     Optional[str]
         membersCanInvite:             Optional[bool]
-        bm:                           Optional[list]
+        bm:                           Optional[List]
         creatoruserId:                Optional[str] = Field(alias="uid")
         visibility:                   Optional[int]
-        bannedMemberUidList:          Optional[list[str]]
+        bannedMemberUidList:          Optional[List[str]]
         lastMembersSummaryUpdateTime: Optional[int]
         fansOnly:                     Optional[bool]
         announcement:                 Optional[str]
@@ -519,9 +520,9 @@ class Thread(BaseModel):
     tipInfo:            Optional[TipInfo]
     userAddedTopicList: Optional[Topic]
     userId:             Optional[str] = Field(alias="uid")
-    membersSummary:     Optional[list[Member]]
+    membersSummary:     Optional[List[Member]]
     membersQuota:       Optional[int]
-    threadId:           Optional[str]
+    chatId:             Optional[str] = Field(alias="threadId")
     keywords:           Optional[str]
     membersCount:       Optional[int]
     strategyInfo:       Optional[Any]
@@ -541,7 +542,7 @@ class Thread(BaseModel):
     latestActivityTime: Optional[datetime]
     comId:              Optional[int] = Field(alias="ndcId")
     createdTime:        Optional[datetime]
-    chatBubbles:        Optional[dict[str, ChatBubble]]
+    chatBubbles:        Optional[Dict[str, ChatBubble]]
 
 
 class Sticker(BaseModel):
@@ -553,17 +554,23 @@ class Sticker(BaseModel):
     smallIcon:           Optional[Any]
     stickerCollectionId: Optional[Any]
     mediumIcon:          Optional[Any]
-    extensions:          Optional[dict]
+    extensions:          Optional[Dict]
     usedCount:           Optional[int]
     mediumIconV2:        Optional[Any]
     createdTime:         Optional[datetime]
     icon:                Optional[str]
 
 
-class Reply(BaseModel):
+class Message(BaseModel):
     class Extensions(BaseModel):
+        class Mention(BaseModel):
+            uid: str
+
         sticker:           Optional[Sticker]
         originalStickerId: Optional[str]
+        mentionedArray:    Optional[List[Mention]]
+        replyMessage:      Optional[Dict]
+        replyMessageId:    Optional[str]
 
     extensions:        Optional[Extensions]
     includedInSummary: Optional[bool]
@@ -579,50 +586,17 @@ class Reply(BaseModel):
     createdTime:       Optional[datetime]
     chatBubbleVersion: Optional[int]
     type:              Optional[int]
+    uid:               Optional[str]
     mediaValue:        Optional[str]
+    nextPageToken:     Optional[str]
+    prevPageToken:     Optional[str]
 
+    @property
+    def reply(self) -> 'Message':
+        Message: 'Message' = getattr(sys.modules[__name__], 'Message')
 
-class Message(BaseModel):
-    class Extensions(BaseModel):
-        sticker:           Optional[Sticker]
-        originalStickerId: Optional[str]
-        replyMessage:      Optional[list[Reply]]
-
-    extensions:        Optional[dict]
-    includedInSummary: Optional[bool]
-    author:            Optional[UserProfile]
-    isHidden:          Optional[bool]
-    chatBubble:        Optional[ChatBubble]
-    messageId:         Optional[str]
-    mediaType:         Optional[int]
-    content:           Optional[str]
-    chatBubbleId:      Optional[str]
-    clientRefId:       Optional[int]
-    threadId:          Optional[str]
-    createdTime:       Optional[datetime]
-    chatBubbleVersion: Optional[int]
-    type:              Optional[int]
-    mediaValue:        Optional[str]
-
-    @validator("extensions")
-    def val_reply(val: dict) -> Optional[list[Reply]]:
-        if val is None:
-            return None
-
-        reply_list = [Reply(**val)]
-        sticker = val.get("sticker")
-        stickerId = val.get("originalStickerId")
-
-        while message := val.get("replyMessage"):
-            reply_list.append(Reply(**message))
-            val = message.get("extensions")
-
-        extensions = {
-            "sticker": sticker,
-            "stickerId": stickerId,
-            "replyes": reply_list
-        }
-        return extensions
+        return Message(**(self.extensions.replyMessage or {
+            "author": {}, "extensions": {"sticker": {}}, "chatBubble": {}}))
 
 
 class Blog(BaseModel):
@@ -633,7 +607,7 @@ class Blog(BaseModel):
                 qhash: Optional[str]
                 title: Optional[str]
 
-            quizQuestionOptList: Optional[list[QuestionOpt]]
+            quizQuestionOptList: Optional[List[QuestionOpt]]
             __disabledLevel__: Optional[int]
 
         status:         Optional[int]
@@ -643,12 +617,12 @@ class Blog(BaseModel):
         createdTime:    Optional[datetime]
         quizQuestionId: Optional[str]
         parentId:       Optional[str]
-        mediaList:      Optional[list[list]]
+        mediaList:      Optional[List[List]]
 
     class Extensions(BaseModel):
         class Style(BaseModel):
             coverMediaIndexList: Optional[Any]
-            backgroundMediaList: Optional[list[list]]
+            backgroundMediaList: Optional[List[List]]
 
         style:                   Optional[Style]
         quizPlayedTimes:         Optional[int]
@@ -661,7 +635,7 @@ class Blog(BaseModel):
     globalVotedValue:      Optional[int]
     votedValue:            Optional[int]
     keywords:              Optional[str]
-    mediaList:             Optional[list[list]]
+    mediaList:             Optional[List[List]]
     style:                 Optional[int]
     totalQuizPlayCount:    Optional[int]
     title:                 Optional[str]
@@ -674,7 +648,7 @@ class Blog(BaseModel):
     status:                Optional[int]
     globalCommentsCount:   Optional[int]
     modifiedTime:          Optional[datetime]
-    quizQuestionList:      Optional[list[QuizQuestion]]
+    quizQuestionList:      Optional[List[QuizQuestion]]
     widgetDisplayInterval: Optional[Any]
     totalPollVoteCount:    Optional[int]
     blogId:                Optional[str]
@@ -687,6 +661,8 @@ class Blog(BaseModel):
     createdTime:           Optional[datetime]
     endTime:               Optional[Any]
     commentsCount:         Optional[int]
+    nextPageToken:         Optional[str]
+    prevPageToken:         Optional[str]
 
 
 class Wiki(BaseModel):
@@ -697,7 +673,7 @@ class Wiki(BaseModel):
     globalVotedValue:    Optional[int]
     votedValue:          Optional[int]
     keywords:            Optional[str]
-    mediaList:           Optional[list[list]]
+    mediaList:           Optional[List[List]]
     style:               Optional[int]
     author:              Optional[UserProfile]
     tipInfo:             Optional[TipInfo]
@@ -724,11 +700,11 @@ class Comment(BaseModel):
     parentType:       Optional[int]
     commentId:        Optional[str]
     parentComId:      Optional[int] = Field(alias="parentNdcId")
-    mediaList:        Optional[list[list]]
+    mediaList:        Optional[List[List]]
     votesSum:         Optional[int]
     author:           Optional[UserProfile]
     content:          Optional[str]
-    extensions:       Optional[dict]
+    extensions:       Optional[Dict]
     parentId:         Optional[str]
     createdTime:      Optional[datetime]
     subcommentsCount: Optional[int]
@@ -736,16 +712,13 @@ class Comment(BaseModel):
 
 
 class Link(BaseModel):
-    class LinkInfo(BaseModel):
-        objectId:   Optional[str]
-        targetCode: Optional[int]
-        comId:      Optional[int] = Field(alias="ndcId")
-        fullPath:   Optional[str]
-        shortCode:  Optional[str]
-        objectType: Optional[int]
-
-    linkInfo:  Optional[LinkInfo]
-    community: Optional[Community]
+    objectId:   Optional[str]
+    targetCode: Optional[int]
+    comId:      Optional[int] = Field(alias="ndcId")
+    fullPath:   Optional[str]
+    shortCode:  Optional[str]
+    objectType: Optional[int]
+    community:  Optional[Community]
 
 
 class Wallet(BaseModel):
@@ -802,24 +775,6 @@ class Membership(BaseModel):
     membershipStatus: Optional[int]
 
 
-class GetMessages(BaseModel):
-    class Paging(BaseModel):
-        next: Optional[str] = Field(alias="nextPageToken")
-        prev: Optional[str] = Field(alias="prevPageToken")
-
-    messageList: Optional[list[Message]]
-    paging:      Optional[Paging]
-
-
-class GetBlogs(BaseModel):
-    class Paging(BaseModel):
-        next: Optional[str] = Field(alias="nextPageToken")
-        prev: Optional[str] = Field(alias="prevPageToken")
-
-    blogList: Optional[list[Message]]
-    paging:  Optional[Paging]
-
-
 class InviteCode(BaseModel):
     status:       Optional[int]
     duration:     Optional[int]
@@ -855,7 +810,7 @@ class StickerCollection(BaseModel):
     stickersCount:       Optional[int]
     ownershipStatus:     Optional[Any]
     usedCount:           Optional[int]
-    availableNdcIds:     Optional[list]
+    availableNdcIds:     Optional[List]
     icon:                Optional[str]
     name:                Optional[str]
     collectionId:        Optional[str]
@@ -875,7 +830,7 @@ class Lottery(BaseModel):
         parentId:    Optional[str]
         createdTime: Optional[datetime]
         awardType:   Optional[int]
-        refObject:   Optional[dict]
+        refObject:   Optional[Dict]
         objectType:  Optional[int]
 
     wallet:     Optional[Wallet]
@@ -968,10 +923,10 @@ class AdminLog(BaseModel):
     operationName:   Optional[str]
     createdTime:     Optional[datetime]
     referTicketId:   Optional[str]
-    extData:         Optional[dict]
+    extData:         Optional[Dict]
     objectId:        Optional[str]
     moderationLevel: Optional[int]
-    refObject:       Optional[dict]
+    refObject:       Optional[Dict]
     author:          Optional[Author]
     objectType:      Optional[int]
     operation:       Optional[int]
@@ -1006,4 +961,4 @@ class Event(BaseModel):
     comId:            Optional[int] = Field(alias="ndcId")
     message:          Optional[Message] = Field(alias="chatMessage")
     alertOption:      Optional[int]
-    membershipStatus: Optional[int]
\ No newline at end of file
+    membershipStatus: Optional[int]
