@@ -3,13 +3,15 @@ from asyncio.events import AbstractEventLoop, get_event_loop
 
 from contextlib import suppress
 from time import time
+from typing import Optional
+from aiohttp import ClientWebSocketResponse
 from aiohttp.client import ClientSession
 from aiohttp.client_exceptions import WSServerHandshakeError
 from aiohttp.client_ws import ClientWebSocketResponse as WSConnection
 from eventemitter.emitter import EventEmitter
 from ujson import loads
 
-from .utils.helpers import _generate_signature
+from .utils.helpers import generate_signature
 from .utils.models import Auth, Event
 
 
@@ -57,7 +59,7 @@ class WebSocketClient:
                 headers = {
                     "NDCDEVICEID": self.auth.deviceId,
                     "NDCAUTH": f"sid={self.auth.sid}",
-                    "NDC-MSG-SIG": await _generate_signature(self._session, data)
+                    "NDC-MSG-SIG": await generate_signature(data)
                 }
 
                 return await self._session.ws_connect(url, headers=headers)
